@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Getopt::Long;
-use Term::TermKey qw( FLAG_UTF8 RES_EOF KEYMOD_CTRL FORMAT_VIM FORMAT_MOUSE_POS );
+use Term::TermKey qw( FLAG_UTF8 RES_EOF FORMAT_VIM FORMAT_MOUSE_POS );
 
 my $mouse;
 GetOptions(
@@ -24,10 +24,6 @@ binmode( STDOUT, ":encoding(UTF-8)" ) if $tk->get_flags & FLAG_UTF8;
 
 while( ( my $ret = $tk->waitkey( my $key ) ) != RES_EOF ) {
    print "Got key: ".$tk->format_key( $key, FORMAT_VIM|FORMAT_MOUSE_POS )."\n";
-
-   last if $key->type_is_unicode and 
-           lc $key->utf8 eq "c" and
-           $key->modifiers & KEYMOD_CTRL;
 }
 
 if( $mouse ) {
